import { Reflector } from '@nestjs/core'
import {
  ExecutionContext,
  Injectable,
  UnauthorizedException,
} from '@nestjs/common'
import { AuthGuard } from '@nestjs/passport'
import 'rxjs'
import { NEED_AUTH_KEY } from '../decorators/need-auth.decorator'

@Injectable()
export class JwtAuthGuard extends AuthGuard('jwt') {
  constructor(private reflector: Reflector) {
    super()
  }

  canActivate(context: ExecutionContext) {
    const needAuth = this.reflector.getAllAndOverride<boolean>(NEED_AUTH_KEY, [
      context.getClass(),
      context.getHandler(),
    ])
    if (needAuth) {
      return super.canActivate(context)
    }
    return true
  }

  handleRequest(err, user, info) {
    // You can throw an exception based on either "info" or "err" arguments
    if (err || !user) {
      throw err || new UnauthorizedException()
    }
    return user
  }
}
